@@ -17,7 +17,7 @@ static const R_CMethodDef Centries[] = {
     {"Cagsurv5",    (DL_FUNC) &agsurv5,   10},
     {"Cagexact",    (DL_FUNC) &agexact,   21},
     {"Cagmart",     (DL_FUNC) &agmart,     9},
-    {"Ccoxdetail",  (DL_FUNC) &coxdetail, 14},
+    {"Ccoxdetail",  (DL_FUNC) &coxdetail, 15},
     {"Ccoxfit5a",   (DL_FUNC) &coxfit5_a, 21},
     {"Ccoxfit5b",   (DL_FUNC) &coxfit5_b, 19},
     {"Ccoxfit5c",   (DL_FUNC) &coxfit5_c,  5},
@@ -36,6 +36,7 @@ static const R_CallMethodDef Callentries[] = {
     {"Cagfit4",       (DL_FUNC) &agfit4,      14},
     {"Cagmart3",      (DL_FUNC) &agmart3,      8},
     {"Cagscore2",     (DL_FUNC) &agscore2,     6},
+    {"Cagscore3",     (DL_FUNC) &agscore3,     7},
     {"Ccdecomp",      (DL_FUNC) &cdecomp,      2},
     {"Ccollapse",     (DL_FUNC) &collapse,     6},
     {"Cconcordance1", (DL_FUNC) &concordance1, 4}, 
@@ -51,6 +52,8 @@ static const R_CallMethodDef Callentries[] = {
     {"Ccoxscore2",    (DL_FUNC) &coxscore2,    6},
     {"Ccoxsurv1",     (DL_FUNC) &coxsurv1,     7},
     {"Ccoxsurv2",     (DL_FUNC) &coxsurv2,     9},
+    {"Ccoxsurv3",     (DL_FUNC) &coxsurv3,     7},
+    {"Ccoxsurv4",     (DL_FUNC) &coxsurv4,     8},
     {"Cfastkm1",      (DL_FUNC) &fastkm1,      3},
     {"Cfastkm2",      (DL_FUNC) &fastkm1,      4},
     {"Cfinegray",     (DL_FUNC) &finegray,     6},
@@ -59,6 +62,7 @@ static const R_CallMethodDef Callentries[] = {
     {"Cgchol_inv",    (DL_FUNC) &gchol_inv,    2},
     {"Cmulticheck",   (DL_FUNC) &multicheck,   6},
     {"Cpyears3b",     (DL_FUNC) &pyears3b,    10},
+    {"Cresidcsum",    (DL_FUNC) &residcsum,    2},
     {"Csurvfitci",    (DL_FUNC) &survfitci,   11},
     {"Csurvfitkm",    (DL_FUNC) &survfitkm,    9},
     {"Csurvfitresid", (DL_FUNC) &survfitresid,10},
